==> nodejs_interop-0.8.0.tar.gz: lib/src/node/modules/require.dart <==
part of nodejs_interop.node;

/// Requires modules.
@JS()
abstract class RequireFunction implements Function {

  /// Modules are cached in this object when they are required.
  ///
  /// By deleting a key value from this object, the next [call] will reload the module.
  /// This does not apply to native addons, for which reloading will result in a [JSError].
  external dynamic get cache;

  /// When a file is run directly from Node.js, [main] is set to its [module].
  /// That means that it is possible to determine whether a file has been run directly by testing `require.main == module`.
  ///
  /// Because [module] provides a `filename` property (normally equivalent to [filename]),
  /// the entry point of the current application can be obtained by checking `require.main.filename`.
  external Module get main;

  /// Looks up the location of a module.
  external ResolveFunction get resolve;

  /// Requires the JavaScript module with the specified [identifier].
  external dynamic call(String identifier);
}

/// Looks up the location of a module.
@JS()
abstract class ResolveFunction implements Function {

  /// Uses the internal [require] machinery to look up the location of a module, and returns the resolved filename.
  external String call(String request, [ResolveFunctionOptions options]);

  /// Returns the paths searched during resolution of the specified [request].
  external List<String> paths(String request);
}

/// Options used to customize the resolution of a module's path.
@JS()
@anonymous
class ResolveFunctionOptions {

  /// Creates a new options object.
  external factory ResolveFunctionOptions({List<String> paths});

  /// The paths to resolve module location from.
  external List<String> get paths;
  external set paths(List<String> value);
}

==> nodejs_interop-0.9.0.tar.gz: lib/src/node/modules/require.dart <==
part of nodejs_interop.node;

/// Requires modules.
@JS('require')
external RequireFunction get require;

/// Requires modules.
@JS()
abstract class RequireFunction {

  /// Modules are cached in this object when they are required.
  ///
  /// By deleting a key value from this object, the next [call] will reload the module.
  /// This does not apply to native addons, for which reloading will result in a [JSError].
  external dynamic get cache;

  /// When a file is run directly from Node.js, [main] is set to its [module].
  /// That means that it is possible to determine whether a file has been run directly by testing `require.main == module`.
  ///
  /// Because [module] provides a `filename` property (normally equivalent to [filename]),
  /// the entry point of the current application can be obtained by checking `require.main.filename`.
  external Module get main;

  /// Looks up the location of a module.
  external ResolveFunction get resolve;

  /// Requires the JavaScript module with the specified [identifier].
  external dynamic call(String identifier);
}

/// Looks up the location of a module.
@JS()
abstract class ResolveFunction {

  /// Uses the internal [require] machinery to look up the location of a module, and returns the resolved filename.
  external String call(String request, [ResolveFunctionOptions options]);

  /// Returns the paths searched during resolution of the specified [request].
  external List<String> paths(String request);
}

/// Options used to customize the resolution of a module's path.
@JS()
@anonymous
class ResolveFunctionOptions {

  /// Creates a new options object.
  external factory ResolveFunctionOptions({List<String> paths});

  /// The paths to resolve module location from.
  external List<String> get paths;
  external set paths(List<String> value);
}
